@@ -23,16 +23,16 @@ import (
 )
 
 type ThanosQuerierTask struct {
-	client             *client.Client
-	factory            *manifests.Factory
-	userWorkloadConfig *manifests.UserWorkloadConfig
+	client  *client.Client
+	factory *manifests.Factory
+	config  *manifests.Config
 }
 
-func NewThanosQuerierTask(client *client.Client, factory *manifests.Factory, cfg *manifests.UserWorkloadConfig) *ThanosQuerierTask {
+func NewThanosQuerierTask(client *client.Client, factory *manifests.Factory, cfg *manifests.Config) *ThanosQuerierTask {
 	return &ThanosQuerierTask{
-		client:             client,
-		factory:            factory,
-		userWorkloadConfig: cfg,
+		client:  client,
+		factory: factory,
+		config:  cfg,
 	}
 }
 
@@ -108,6 +108,16 @@ func (t *ThanosQuerierTask) Run() error {
 		return errors.Wrap(err, "creating Thanos Querier RBAC proxy Secret failed")
 	}
 
+	rs, err = t.factory.ThanosQuerierRBACProxyRulesSecret()
+	if err != nil {
+		return errors.Wrap(err, "initializing Thanos Querier RBAC proxy rules Secret failed")
+	}
+
+	err = t.client.CreateIfNotExistSecret(rs)
+	if err != nil {
+		return errors.Wrap(err, "creating Thanos Querier RBAC proxy rules Secret failed")
+	}
+
 	sa, err := t.factory.ThanosQuerierServiceAccount()
 	if err != nil {
 		return errors.Wrap(err, "initializing Thanos Querier ServiceAccount failed")
@@ -138,7 +148,7 @@ func (t *ThanosQuerierTask) Run() error {
 		return errors.Wrap(err, "reconciling Thanos Querier ClusterRoleBinding failed")
 	}
 
-	grpcTLS, err := t.factory.GRPCSecret(nil)
+	grpcTLS, err := t.factory.GRPCSecret()
 	if err != nil {
 		return errors.Wrap(err, "initializing Thanos Querier GRPC secret failed")
 	}
@@ -193,7 +203,7 @@ func (t *ThanosQuerierTask) Run() error {
 			return errors.Wrap(err, "syncing Thanos Querier trusted CA bundle ConfigMap failed")
 		}
 
-		dep, err := t.factory.ThanosQuerierDeployment(s, t.userWorkloadConfig.IsEnabled(), trustedCA)
+		dep, err := t.factory.ThanosQuerierDeployment(s, t.config.IsUserWorkloadEnabled(), trustedCA)
 		if err != nil {
 			return errors.Wrap(err, "initializing Thanos Querier Deployment failed")
 		}
@@ -204,5 +214,25 @@ func (t *ThanosQuerierTask) Run() error {
 		}
 	}
 
+	tqsm, err := t.factory.ThanosQuerierServiceMonitor()
+	if err != nil {
+		return errors.Wrap(err, "initializing Thanos Querier ServiceMonitor failed")
+	}
+
+	err = t.client.CreateOrUpdateServiceMonitor(tqsm)
+	if err != nil {
+		return errors.Wrap(err, "reconciling Thanos Querier ServiceMonitor failed")
+	}
+
+	tqpr, err := t.factory.ThanosQuerierPrometheusRule()
+	if err != nil {
+		return errors.Wrap(err, "initializing Thanos Querier PrometheusRule failed")
+	}
+
+	err = t.client.CreateOrUpdatePrometheusRule(tqpr)
+	if err != nil {
+		return errors.Wrap(err, "reconciling Thanos Querier PrometheusRule failed")
+	}
+
 	return nil
 }
